# Mozilla Tracking Protection Tools

A collection of tools for working with and analyzing Firefox's Tracking
Protection.

## Tools

1. **DisconnectParser**: A python parser for the Disconnect Tracking Protection
   list.
